//----------------------------------------------------------------------
//
// Copyright (C) OPTOELECTRONICS CO., LTD.  All rights reserved.
//
//
//	System Control API declarations
//
//
// Module Name:
//
//		SYSCtl.h
//
// Abstract:
//
//		This file defines APIs to the OPTICON System Control library.
//
// Revision:
//
//	     Rev.0.97	2010/8/31		Modified for H-21
//		
//	
//		
//
//----------------------------------------------------------------------
#ifndef _SYSCTL_H_
#define _SYSCTL_H_

//
// SYSCtl definition
//

//
// The range of the backlight level is from SYS_BACKLIGHT_LEVEL_MINIMUM to SYS_BACKLIGHT_LEVEL_MAXIMUM.
//
#define    SYS_BACKLIGHT_LEVEL_MINIMUM     0  // Minimum backlight level
#define    SYS_BACKLIGHT_LEVEL_MAXIMUM     7  // Maximum backlight level

//
// The value of the power mode.
//
#define    SYS_POWER_BATTERY_MODE    1  // battery power mode
#define    SYS_POWER_EXTERNAL_MODE   2  // external power mode

//
// The value of the backlight timeout 
//
#define    BACKLIGHT_TIMEOUT_INDEFINITELY  0      // Never time out
#define    BACKLIGHT_TIMEOUT_TEN_SEC       10     // battery mode only
#define    BACKLIGHT_TIMEOUT_THIRTY_SEC    30     // battery mode only
#define    BACKLIGHT_TIMEOUT_ONE_MIN       60     // battery mode & external power mode
#define    BACKLIGHT_TIMEOUT_TWO_MIN       120    // battery mode & external power mode
#define    BACKLIGHT_TIMEOUT_THREE_MIN     180    // battery mode & external power mode
#define    BACKLIGHT_TIMEOUT_FOUR_MIN      240    // battery mode & external power mode
#define    BACKLIGHT_TIMEOUT_FIVE_MIN      300    // battery mode & external power mode
#define    BACKLIGHT_TIMEOUT_SIX_MIN       360    // external power mode only
#define    BACKLIGHT_TIMEOUT_SEVEN_MIN     420    // external power mode only
#define    BACKLIGHT_TIMEOUT_EIGHT_MIN     480    // external power mode only
#define    BACKLIGHT_TIMEOUT_NINE_MIN      540    // external power mode only
#define    BACKLIGHT_TIMEOUT_TEN_MIN       600    // external power mode only

//
// The value of special keys.
//  SYS_SPECIALKEY_XXX bit flags set in SysSetSpecialKeyStatus dwStatusFlag parameter. 
//
#define    SYS_SPECIALKEY_NONE             0     // none key is enabled
#define    SYS_SPECIALKEY_VOLUME_BUTTON    0x01  // "Volume" button is enabled
#define    SYS_SPECIALKEY_CAMERA_BUTTON    0x02  // "Camera" button is enabled
#define    SYS_SPECIALKEY_PHONE_KEY        0x04  // "Send Phone" key & "End Phone" key are enabled
#define    SYS_SPECIALKEY_HOME_KEY         0x08  // "Home" key is enabled
#define    SYS_SPECIALKEY_OK_KEY           0x10  // "OK" key is enabled

//
// The range of the key backlight timeout is from SYS_KEYBACKLIGHT_TIME_MINIMUM to SYS_KEYBACKLIGHT_TIME_MAXIMUM.
//
#define    SYS_KEYBACKLIGHT_TIME_MINIMUM     1   // The minimum key backlight timeout is 1 second.
#define    SYS_KEYBACKLIGHT_TIME_MAXIMUM     10  // The maximum key backlight timeout is 10 seconds.

//
// The value of the WLAN power saving mode
//
#define    SYS_WIFI_POWER_POWER    0  // Power saving priority
#define    SYS_WIFI_POWER_SPEED    1  // Transmission speed priority
#define    SYS_WIFI_POWER_AUTO     2  // Automation

//
// The value of the WLAN regulatory type.
//
#define    SYS_WLAN_REGULATORY_US        0x10  // US
#define    SYS_WLAN_REGULATORY_CANADA    0x20  // Canada
#define    SYS_WLAN_REGULATORY_EU        0x30  // EU (ETSI)
#define    SYS_WLAN_REGULATORY_JAPAN     0x40  // Japan (TELEC)
#define    SYS_WLAN_REGULATORY_OTHERS    0x00  // Others

//
// The value of WLAN power status
//
#define    SYS_WLAN_POWER_OFF    0  // power off
#define    SYS_WLAN_POWER_ON     1  // power on

//
// The range of the WLAN signal level is from SYS_WLAN_SIGNAL_LEVEL_MINIMUM to SYS_WLAN_SIGNAL_LEVEL_MAXIMUM.
//
#define    SYS_WLAN_SIGNAL_LEVEL_MINIMUM     0   // Minimum signal level
#define    SYS_WLAN_SIGNAL_LEVEL_MAXIMUM     25  // Maximum signal level

//
// The value of the suspend time.
//
#define    SUSPEND_TIME_INDEFINITELY  0       // Never auto-suspend
#define    SUSPEND_TIME_ONE_MIN       60      // battery mode & external power mode
#define    SUSPEND_TIME_TWO_MIN       120     // battery mode & external power mode
#define    SUSPEND_TIME_THREE_MIN     180     // battery mode & external power mode
#define    SUSPEND_TIME_FOUR_MIN      240     // battery mode & external power mode
#define    SUSPEND_TIME_FIVE_MIN      300     // battery mode & external power mode
#define    SUSPEND_TIME_TEN_MIN       600     // external power mode only
#define    SUSPEND_TIME_FIFTEEN_MIN   900     // external power mode only
#define    SUSPEND_TIME_THIRTY_MIN    1800    // external power mode only

//
// The value of wake source key.
// SYS_WAKESOURCE_XXX bit flags set in SysSetWakeSources dwSourceFlag parameter.
//
#define    SYS_WAKESOURCE_NONE          0     // none wake source
#define    SYS_WAKESOURCE_USB_CRADLE    0x01  // Reserved. Due to H-21 doesn't support this feature. 
#define    SYS_WAKESOURCE_APP_KEY       0x02  // Wake on application keys.
#define    SYS_WAKESOURCE_BLUETOOTH     0x04  // Reserved. Due to H-21 doesn't support this feature. 
#define    SYS_WAKESOURCE_WLAN          0x08  // Wake on LAN.
#define    SYS_WAKESOURCE_ACADAPTER     0x10  // Reserved. Due to H-21 doesn't support this feature.

//
// The range of the vibrating time is from SYS_VIBRATE_TIME_MINIMUM to SYS_VIBRATE_TIME_MAXIMUM.
//
#define    SYS_VIBRATE_TIME_MINIMUM     10     // The minimum is SYS_VIBRATE_TIME_MINIMUM milliseconds.
#define    SYS_VIBRATE_TIME_MAXIMUM     10000  // The maximum is SYS_VIBRATE_TIME_MAXIMUM milliseconds.

#ifdef __cplusplus
extern "C" {
#endif
//
// SYSCtl Functions
//


//
// SysGetSerialNumber
// Get serial number of the device .
//
BOOL SysGetSerialNumber(LPTSTR lpszSNString, DWORD dwSNStringLength);

//
// SysGetConfigNumber
// Get the config number of the device.
//
BOOL SysGetConfigNumber(LPTSTR lpszCNString, DWORD dwCNStringLength);

//
// SysGetModelName
// Get mode name.
//
BOOL SysGetModelName(LPTSTR lpszMNString, DWORD dwMNStringLength);

//
// SysGetROMVersion
// Get ROM version
//
BOOL SysGetROMVersion(LPTSTR lpszROMVersion, DWORD dwVersionLength);


//
// SysEnableAGPS
// Enable the AGPS.
//
BOOL SysEnableAGPS(BOOL bEnable);

//
// SysGetAGPSState
// Get the AGPS state.
//
BOOL SysGetAGPSState(BOOL* pbState);


//
// SysGetBacklightLevel
// Get the backlight level for battery power mode or external power mode.
// dwPowerMode : SYS_POWER_BATTERY_MODE,SYS_POWER_EXTERNAL_MODE
//
BOOL SysGetBacklightLevel(DWORD dwPowerMode,BYTE* pbLevel);

//
// SysSetBacklightLevel
// Set the backlight level for battery power mode or external power mode.
// dwPowerMode : SYS_POWER_BATTERY_MODE,SYS_POWER_EXTERNAL_MODE
// dwLevel : The minimum is SYS_BACKLIGHT_LEVEL_MINIMUM,the maximum is SYS_BACKLIGHT_LEVEL_MAXIMUM
//
BOOL SysSetBacklightLevel(DWORD dwPowerMode,BYTE bLevel);

//
// SysGetBacklightTimeout
// Get the backlight timeout for the battery power mode and the external power mode.
// dwPowerMode : SYS_POWER_BATTERY_MODE,SYS_POWER_EXTERNAL_MODE
//
BOOL SysGetBacklightTimeout(DWORD dwPowerMode,DWORD* lpdwBacklightTimeout);

//
// SysSetBacklightTimeout
// Set the backlight timeout for the battery power mode and the external power mode.
// dwPowerMode : SYS_POWER_BATTERY_MODE,SYS_POWER_EXTERNAL_MODE
// dwBacklightTimeout : BACKLIGHT_TIMEOUT_XXX
//
BOOL SysSetBacklightTimeout(DWORD dwPowerMode,DWORD dwBacklightTimeout);

//
// SysEnableAutoAdjustBL
// Enable auto adjust backlight.
//
BOOL SysEnableAutoAdjustBL(BOOL bEnable);

//
// SysGetAutoAdjustBLState
// Get auto adjust backlight state.
//
BOOL SysGetAutoAdjustBLState(BOOL* pbState);


//
// SysSetSpecialKeyStatus
// Set special key status.Parameters "dwStatusFlag"(bitmask) as follows:
//   SYS_SPECIALKEY_VOLUME_BUTTON ("Volume" button)
//   SYS_SPECIALKEY_CAMERA_BUTTON    ("Camera" button)
//   SYS_SPECIALKEY_PHONE_KEY    ("Send Phone" key & "End Phone" key)
//   SYS_SPECIALKEY_HOME_KEY    ("Home" key)
//   SYS_SPECIALKEY_OK_KEY    ("OK" key)
//
BOOL SysSetSpecialKeyStatus(DWORD dwStatusFlag);

//
// SysGetSpecialKeyStatus
// Get special key status.
//
BOOL SysGetSpecialKeyStatus(DWORD* lpdwStatusFlag);


//
// SysEnableKeyBacklight
// Enable the key backlight.
//
BOOL SysEnableKeyBacklight(BOOL bEnable);

//
// SysGetKeyBacklightState
// Get the key backlight state.
//
BOOL SysGetKeyBacklightState(BOOL* pbState);

//
// SysGetKeyBacklightTimeout
// Get key backlight timeout.
//
BOOL SysGetKeyBacklightTimeout(DWORD* lpdwTime);

//
// SysSetKeyBacklightTimeout
// Set the timeout for key backlight.
// dwTime : The minimum is SYS_KEYBACKLIGHT_TIME_MINIMUM second,
//          the maximum is SYS_KEYBACKLIGHT_TIME_MAXIMUM seconds.
//
BOOL SysSetKeyBacklightTimeout(DWORD dwTime);


//
// SysEnableTouchPanel
// Enable touch panel.
//
BOOL SysEnableTouchPanel(BOOL bEnable);

//
// SysGetTouchPanelStatus
// Get touch panel status.
//
BOOL SysGetTouchPanelStatus(BOOL* pbEnable);


//
// SysEnableMotionSensor
// Enable motion sensor.
//
BOOL SysEnableMotionSensor(BOOL bEnable);

//
// SysGetMotionSensorState
// Get motion sensor state.
//
BOOL SysGetMotionSensorState(BOOL* pbEnable);


//
// SysSetVibrator
// Vibrate dwTimeMilliSecond millisecond.
// dwTimeMilliSecond : The minimum is SYS_VIBRATE_TIME_MINIMUM milliseconds,
//                     the maximum is SYS_VIBRATE_TIME_MAXIMUM milliseconds.
//
BOOL SysSetVibrator(DWORD dwTimeMilliSecond);

//
// SysStopVibrator
// Stop vibrating.
//
BOOL SysStopVibrator(VOID);


//
// SysWLANGetPowerSavingMode
// Get the power saving mode for WLAN.
//
BOOL SysWLANGetPowerSavingMode(DWORD* lpdwMode);

//
// SysWLANSetPowerSavingMode
// Set the the power saving mode for WLAN.
// dwMode : SYS_WIFI_POWER_XXX
//
BOOL SysWLANSetPowerSavingMode(DWORD dwMode);

//
// SysGetWLANRegulatory
// Get the WLAN regulatory.
//
BOOL SysGetWLANRegulatory(DWORD* lpdwRegulatory);

//
// SysSetWLANRegulatory
// Set the WLAN regulatory.
// dwRegulatory : SYS_WLAN_REGULATORY_XXX
//
BOOL SysSetWLANRegulatory(DWORD dwRegulatory);


//
// SysGetWLANPower
// Get power of WLAN.
//
BOOL SysGetWLANPower(DWORD* lpdwPowerStatus);

//
// SysSetWLANPower
// Set power of WLAN.
// dwPowerStatus : SYS_WLAN_POWER_OFF, SYS_WLAN_POWER_ON
//
BOOL SysSetWLANPower(DWORD dwPowerStatus);

//
// SysGetWLANSignalLevel
// Get WLAN signal level.
// lpdwSingalLevel : The minimum is SYS_WLAN_SIGNAL_LEVEL_MINIMUM, the maximum is SYS_WLAN_SIGNAL_LEVEL_MAXIMUM.
//
BOOL SysGetWLANSignalLevel(DWORD* lpdwSingalLevel);


//
// SysSetSuspendTime
// Set the time to suspend if not use the device.
// dwPowerMode : SYS_POWER_BATTERY_MODE,SYS_POWER_EXTERNAL_MODE
// dwSuspendTime : SUSPEND_TIME_XXX
//
BOOL SysSetSuspendTime(DWORD dwPowerMode, DWORD dwSuspendTime);

//
// SysGetSuspendTime
// Get the time to suspend if not use the device.
// dwPowerMode : SYS_POWER_BATTERY_MODE,SYS_POWER_EXTERNAL_MODE
//
BOOL SysGetSuspendTime(DWORD dwPowerMode, DWORD* lpdwSuspendTime);

//
// SysGetPowerKeyStatus
// Get the power key status.
//
BOOL SysGetPowerKeyStatus(BOOL* pbEnable);

//
// SysEnablePowerKey
// Enable/Disable the power key.
//
BOOL SysEnablePowerKey(BOOL bEnable);

//
// SysSetWakeSources
// Set wake source.Parameters "dwSourceFlag"(bitmask) as follows:
//   SYS_WAKESOURCE_USB_CRADLE (Reserved. Due to H-21 doesn't support this feature.) 
//   SYS_WAKESOURCE_APP_KEY  
//   SYS_WAKESOURCE_BLUETOOTH  (Reserved. Due to H-21 doesn't support this feature.) 
//   SYS_WAKESOURCE_WLAN  
//   SYS_WAKESOURCE_ACADAPTER  (Reserved. Due to H-21 doesn't support this feature.)
//
BOOL SysSetWakeSources(DWORD dwSourceFlag);

//
// SysGetWakeSources
// Get wake source.
//
BOOL SysGetWakeSources(DWORD* lpdwSourceFlag);

//
// SysShutDown
// Shut down the device.
//
BOOL SysShutDown(VOID);


//
// SysGetLibraryVersion
// Get the version of SYSCtl.lib.
//
BOOL SysGetLibraryVersion(LPTSTR lpszLVString, DWORD dwLVStringLength);

#ifdef __cplusplus
}
#endif

#endif // _SYSCTL_H_